#ifndef INPUT_H
#define INPUT_H

/* memory for vertices and aedges is allocated in
 * LENGTH_OF_BLOCK * sizeof ( vertex or aedge, respectively ) bytes long segments;
 * LENGTH_OF_BLOCK should be at least 3 */
#define LENGTH_OF_BLOCK    1024       

/* memory for storing a logical line of text of input file is allocated in 
 * INIT_BUFFER_SIZE bytes long segments */
#define INIT_BUFFER_SIZE   256       

/* Procedure getln reads a line from the file file and stores it in a buffer that is
 * addressed by the pointer (*lineptr). No end-line character is stored at the end
 * of the line in the buffer but a single terminating '\0' character is added.
 *
 * If a backslash character is hit during reading the line from the file, it is replaced 
 * by a space character, the rest of the current line is ignored, and the next line of
 * the file is appended to the buffer.
 *
 * The procedure supposes that a memory space of length (*size) characters is allocated 
 * for the line beforehand and reallocates more memory if needed. If there is such
 * a need, the memory is reallocated with addition of space for more INIT_BUFFER_SIZE 
 * characters. The INIT_BUFFER_SIZE macro is defined in the 'header.h' file.
 * The length of the (re-)allocated memory is stored in the variable addressed by the
 * pointer size. 
 * 
 * For portability reasons, any sequence of LF and CR characters is considered as the end 
 * of a line; as a result, blank lines of the file are ignored except for the first
 * line of the file.
 */
void getln ( char **lineptr, long *size, FILE *file );

/* procedure input reads the data from the input file and creates the array
 * of strings that represent vertices and the array of all internal edges; it also
 * temporarily creates and uses the array of all sides (edges) of all triangles 
 * (i.e. the array of aedges)
 *
 *     fname     the name of the input .obj file
 */
void input ( char *fname );

/* function compare_ord defines ordinary numerical comparison of long int numbers 
 */
int compare_ord ( const void *a, const void *b );

#endif
